@@ -18,6 +18,8 @@ typedef void (*append_t)(StringInfo dst, const char *src, int srclen);
 
 extern void normalize_utf8(StringInfo dst, const char *src, size_t srclen, append_t append);
 extern void normalize_eucjp(StringInfo dst, const char *src, size_t srclen, append_t append);
+extern char *lexize_utf8(const char *str, size_t len);
+extern char *lexize_eucjp(const char *str, size_t len);
 extern void hiragana_utf8(StringInfo dst, const char *src, size_t srclen);
 extern void hiragana_eucjp(StringInfo dst, const char *src, size_t srclen);
 extern void katakana_utf8(StringInfo dst, const char *src, size_t srclen);
